@@ -19,6 +19,7 @@
 #include "k3b_i18n.h"
 
 #include <KProcess>
+#include <kio_version.h>
 #include <KIO/Job>
 #include <KIO/StatJob>
 #include <KMountPoint>
@@ -238,7 +239,11 @@ KIO::filesize_t K3b::imageFilesize( const QUrl& url )
     {
         QUrl nextUrl( url );
         nextUrl.setPath(nextUrl.path() + '.' + QString::number(cnt).rightJustified( 3, '0' ));
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 240, 0)
+        KIO::StatJob* statJob = KIO::stat(nextUrl, KIO::StatJob::SourceSide, KIO::StatDefaultDetails, KIO::HideProgressInfo);
+#else
         KIO::StatJob* statJob = KIO::statDetails(nextUrl, KIO::StatJob::SourceSide, KIO::StatDefaultDetails, KIO::HideProgressInfo);
+#endif
         if (statJob->exec())
             size += K3b::filesize(nextUrl);
         else
